@@ -9,7 +9,7 @@
 #include "konqframe.h"
 #include "konqview.h"
 #include "konqmainwindow.h"
-#include "konqsettingsxt.h"
+#include "konqsettings.h"
 
 #include <QApplication>
 #include <QMouseEvent>
@@ -92,9 +92,9 @@ bool KonqMouseEventFilter::eventFilter(QObject *obj, QEvent *e)
         QMouseEvent *ev = static_cast<QMouseEvent*>(e);
         if (m_bBackRightClick && ev->buttons() & Qt::RightButton) {
             qApp->removeEventFilter(this);
-            QMouseEvent me(QEvent::MouseButtonPress, ev->pos(), Qt::RightButton, Qt::RightButton, Qt::NoModifier);
+            QMouseEvent me(QEvent::MouseButtonPress, ev->pos(), ev->globalPosition(), Qt::RightButton, Qt::RightButton, Qt::NoModifier);
             QApplication::sendEvent(obj, &me);
-            QContextMenuEvent ce(QContextMenuEvent::Mouse, ev->pos(), ev->globalPos());
+            QContextMenuEvent ce(QContextMenuEvent::Mouse, ev->pos(), ev->globalPosition().toPoint());
             QApplication::sendEvent(obj, &ce);
             qApp->installEventFilter(this);
         }
@@ -116,5 +116,5 @@ bool KonqMouseEventFilter::eventFilter(QObject *obj, QEvent *e)
 
 void KonqMouseEventFilter::reparseConfiguration()
 {
-    m_bBackRightClick = KonqSettings::backRightClick();
+    m_bBackRightClick = Konq::Settings::backRightClick();
 }
